@@ -1,6 +1,6 @@
 package Acme::Boolean;
 # ABSTRACT: There is more then one way to be true.
-$Acme::Boolean::VERSION = '0.6';
+$Acme::Boolean::VERSION = '0.7';
 use strict;
 use warnings;
 
@@ -15,15 +15,20 @@ my @true = map {
     $_;
 } map { ($_, uc($_)) } qw(yes verifiable trusty accurate actual appropriate authentic authoritative correct dependable direct exact factual fitting genuine honest indubitable kosher lawful legal legitimate natural normal perfect precise proper pure regular right rightful sincere straight trustworthy truthful typical undeniable undesigning undoubted unerring unfaked unfeigned unquestionable veracious veridical veritable wash);
 
+sub NO { false }
+sub no { false }
+
 my @false = map {
     *{$_} = \&false;
     $_;
-} map { ($_, uc($_)) } qw(no untrue wrong incorrect errorneous fallacious untruthful nah apocryphal beguiling bogus casuistic concocted counterfactual deceitful deceiving delusive dishonest distorted erroneous ersatz fake fanciful faulty fictitious fishy fraudulent illusive imaginary improper inaccurate inexact invalid lying mendacious misleading misrepresentative mistaken phony sham sophistical specious spurious unfounded unreal unsound);
+} map { ($_, uc($_)) } qw(untrue wrong incorrect errorneous fallacious untruthful nah apocryphal beguiling bogus casuistic concocted counterfactual deceitful deceiving delusive dishonest distorted erroneous ersatz fake fanciful faulty fictitious fishy fraudulent illusive imaginary improper inaccurate inexact invalid lying mendacious misleading misrepresentative mistaken phony sham sophistical specious spurious unfounded unreal unsound);
+
+push @false, 'NO', 'no';
 
 my @ad = map {
     *{$_} = sub($) { shift; };
     $_;
-} map { ($_, uc($_)) } qw(so totally very definitely really certainly surely unquestionably undoubtedly absolutely exactly);
+} map { ($_, uc($_)) } qw(just so totally very definitely really certainly surely unquestionably undoubtedly absolutely exactly);
 
 sub NOT($) { not shift }
 push @ad, 'NOT';
@@ -49,7 +54,7 @@ Acme::Boolean - There is more then one way to be true.
 
 =head1 VERSION
 
-version 0.6
+version 0.7
 
 =head1 SYNOPSIS
 
@@ -109,7 +114,7 @@ At this moment you can use these adjectives in front of any of those
 true/false vocabularies:
 
 so totally very definitely really certainly surely unquestionably
-undoubtedly absolutely.
+just undoubtedly absolutely.
 
 Adjectives can be stacked too:
 
@@ -125,7 +130,7 @@ although that may accidently include some emotions to the logic.
 In fact, if strong emotion is intentionally wished for, all the introduced
 words comes with a all caps version at your disposal.
 
-Here are some notable examles:
+Here are some notable examples:
 
     my $p = SO true;
     my $q = NOT exactly lying;
@@ -133,11 +138,31 @@ Here are some notable examles:
 Be notified that readers my not preceive such embedded emotion the same
 way writers put it.
 
-=head2 Special mention
+=head2 Special forms
 
 The builtin keyword C<not> that flips true/false value is a nice
 add-on to boolean words but the all caps version is not provided by
-perl. There it is provided by this module.
+perl. Therefore C<Acme::Boolean> completes perl by providing the all
+caps C<NOT> unary operator.
+
+    my $f = NOT yes; # false
+    my $t = NOT NOT yes; # true
+
+The keyword C<NO> is also stackable this expression means NO:
+
+    NO NO NO NO NO
+
+Be very careful on using NO with other Acme::Boolean keywords for it
+always reduce everything on its right-hand side to a false
+value. After all, NO means NO. So this means NO.
+
+    NO really not fishy
+
+However, this expression means YES:
+
+    NO, really not fishy
+
+Be aware of the significance of punctuations.
 
 =head2 SEE ALSO
 
